from rasa_contrib.nlu.featurizers import BertTextFeaturizer, BertCharFeaturizer
from rasa_contrib.nlu.extractors import BilstmCrfTensorFlowEntityExtractor
from rasa_contrib.nlu.classifiers import TextCnnTensorFlowClassifier, DenseNetworkTensorFlowClassifier
from rasa_contrib.nlu.utils import TensorflowNLP, PaddleNLP



from typing import Any, Dict, Optional, Text, List


from rasa.nlu.extractors.extractor import EntityExtractor
from rasa.nlu.model import Metadata
from rasa.nlu.training_data import Message, TrainingData

from data_tool.rule_date.date_parser import time_extract


class RegexDateExtractor(EntityExtractor):
    provides = ["entities"]

    defaults = {
        "entity_name": "time"
    }

    def __init__(
            self,
            component_config: Optional[Dict[Text, Any]] = None,
    ) -> None:
        super(RegexDateExtractor, self).__init__(component_config)

    def process(self, message: Message) -> List[Dict[Text, Any]]:
        json_ents = []
        date_times = time_extract(message.text)
        for date_time in date_times:
            json_ents.append({
                'start': -1,
                'end': -1,
                'value': date_time,
                'entity': self.component_config['entity_name']
            })
        message.set(
            "entities", message.get("entities", []) + json_ents, add_to_output=True
        )


from rasa_contrib.nlu.classifiers.text_cnn_paddle_classifier import TextCnnPaddleClassifier
from rasa_contrib.nlu.classifiers.text_cnn_tf_classifier import TextCnnTensorFlowClassifier
from rasa_contrib.nlu.classifiers.dense_network_tf_classifier import DenseNetworkTensorFlowClassifier



import os

import setuptools
from setuptools import setup

tests_requires = [
    "pytest",
    "requests",
]

install_requires = [
    "rasa",
    "data-tool",
]


setup(
    name=os.getenv("_PKG_NAME", "rasa_exp"),  # _PKG_NAME will be used in Makefile for dev release
    version="0.0.1",
    packages=setuptools.find_packages(),
    include_package_data=True,
    url="https://github.com/shfshf/rasa_exp",
    license="Apache 2.0",
    author="Hanfeng Song",
    author_email="1316478299@qq.com",
    description="rasa_exp",
    install_requires=install_requires,
)
